class DotStringsParser

  REGEX_QUOTED = /\"((\\\"|[^\"])+)\"/
  REGEX_KEY_VALUE = /#{REGEX_QUOTED}\s*=\s*#{REGEX_QUOTED}/

  def initialize
    @hash = {}
  end

  def convert_to_array(line)
    if pair_match = line.match(REGEX_KEY_VALUE)
      pair_string = pair_match.to_s
      pair_array = pair_string.partition(/\s*=\s*/)
      pair_array.map do |index|
        index.gsub!(/(^"|"$)/, "")
      end
      @hash[pair_array[0]] = pair_array[2]
    end
  end

  def to_hash(file)
    File.open(file, "r") do |file|
      content = file.read
      content.each_line do |line|
        convert_to_array line
      end
    end
    @hash
  end

  def writeFile(fileName,fileText)
    File.open(fileName, "a+") do |file|
      file.write(fileText) 
      file.close  
    end
  end

  def getWithCss(cssName,html)
    withCss =  %Q(
      <html>
        <head>
          <meta charset="UTF-8">
          <link rel="stylesheet" href="#{cssName}">
        </head>
        <body>
          #{html}
        </body>
      </html>
      )
    withCss
  end

  def self.parse
    new
  end
end

require 'json'
require 'fileutils'
require 'pathname'

# First argument is locale shorten 'en' 'de'
# Second argument is folder containing htmls
# Third argument is file pointing to ios strings
# Fourth argument is css string to add to html ie '../../info-page.css'
## terminal example:
##  ruby replace.rb it FAQ_Stuff/ FAQ_Stuff/it.lproj/Localizable.strings "../../faq-page.css"

outputFile=__dir__ + "/htmlFiles-" + ARGV[0]
if File.directory?(outputFile)
  FileUtils.remove_dir(outputFile)
end
Dir.mkdir(outputFile)

htmlFiles = Dir.glob(ARGV[1] + "*.html")
hash = DotStringsParser.parse.to_hash(ARGV[2])
htmlFiles.each do |x| 
  html = File.read(x)
  hash.each do |key, value|
    html = html.gsub('>' + key + '<', '>' + value + '<')
  end
  withCss = DotStringsParser.parse.getWithCss(ARGV[3],html)
  DotStringsParser.parse.writeFile(outputFile +"/" + File.basename(x),withCss)
end

